<?php
/**
 * Builds our Customizer controls.
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

add_action( 'customize_register', 'saraswati_set_customizer_helpers', 1 );
/**
 * Set up helpers early so they're always available.
 * Other modules might need access to them at some point.
 *
 */
function saraswati_set_customizer_helpers( $wp_customize ) {
	// Load helpers
	require_once trailingslashit( get_template_directory() ) . 'inc/customizer/customizer-helpers.php';
}

if ( ! function_exists( 'saraswati_customize_register' ) ) {
	add_action( 'customize_register', 'saraswati_customize_register' );
	/**
	 * Add our base options to the Customizer.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	function saraswati_customize_register( $wp_customize ) {
		// Get our default values
		$defaults = saraswati_get_defaults();

		// Load helpers
		require_once trailingslashit( get_template_directory() ) . 'inc/customizer/customizer-helpers.php';

		if ( $wp_customize->get_control( 'blogdescription' ) ) {
			$wp_customize->get_control('blogdescription')->priority = 3;
			$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
		}

		if ( $wp_customize->get_control( 'blogname' ) ) {
			$wp_customize->get_control('blogname')->priority = 1;
			$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
		}

		if ( $wp_customize->get_control( 'custom_logo' ) ) {
			$wp_customize->get_setting( 'custom_logo' )->transport = 'refresh';
		}

		// Add control types so controls can be built using JS
		if ( method_exists( $wp_customize, 'register_control_type' ) ) {
			$wp_customize->register_control_type( 'Saraswati_Customize_Misc_Control' );
			$wp_customize->register_control_type( 'Saraswati_Range_Slider_Control' );
		}

		// Add upsell section type
		if ( method_exists( $wp_customize, 'register_section_type' ) ) {
			$wp_customize->register_section_type( 'Saraswati_Upsell_Section' );
		}

		// Add selective refresh to site title and description
		if ( isset( $wp_customize->selective_refresh ) ) {
			$wp_customize->selective_refresh->add_partial( 'blogname', array(
				'selector' => '.main-title a',
				'render_callback' => 'saraswati_customize_partial_blogname',
			) );

			$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
				'selector' => '.site-description',
				'render_callback' => 'saraswati_customize_partial_blogdescription',
			) );
		}

		// Remove title
		$wp_customize->add_setting(
			'saraswati_settings[hide_title]',
			array(
				'default' => $defaults['hide_title'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_checkbox'
			)
		);

		$wp_customize->add_control(
			'saraswati_settings[hide_title]',
			array(
				'type' => 'checkbox',
				'label' => __( 'Hide site title', 'saraswati' ),
				'section' => 'title_tagline',
				'priority' => 2
			)
		);

		// Remove tagline
		$wp_customize->add_setting(
			'saraswati_settings[hide_tagline]',
			array(
				'default' => $defaults['hide_tagline'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_checkbox'
			)
		);

		$wp_customize->add_control(
			'saraswati_settings[hide_tagline]',
			array(
				'type' => 'checkbox',
				'label' => __( 'Hide site tagline', 'saraswati' ),
				'section' => 'title_tagline',
				'priority' => 4
			)
		);

		$wp_customize->add_setting(
			'saraswati_settings[retina_logo]',
			array(
				'type' => 'option',
				'sanitize_callback' => 'esc_url_raw'
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'saraswati_settings[retina_logo]',
				array(
					'label' => __( 'Retina Logo', 'saraswati' ),
					'section' => 'title_tagline',
					'settings' => 'saraswati_settings[retina_logo]',
					'active_callback' => 'saraswati_has_custom_logo_callback'
				)
			)
		);

		$wp_customize->add_setting(
			'saraswati_settings[side_inside_color]', array(
				'default' => $defaults['side_inside_color'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_hex_color',
				'transport' => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'saraswati_settings[side_inside_color]',
				array(
					'label' => __( 'Inside padding', 'saraswati' ),
					'section' => 'colors',
					'settings' => 'saraswati_settings[side_inside_color]',
					'active_callback' => 'saraswati_is_side_padding_active',
				)
			)
		);

		$wp_customize->add_setting(
			'saraswati_settings[text_color]', array(
				'default' => $defaults['text_color'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_hex_color',
				'transport' => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'saraswati_settings[text_color]',
				array(
					'label' => __( 'Text Color', 'saraswati' ),
					'section' => 'colors',
					'settings' => 'saraswati_settings[text_color]'
				)
			)
		);

		$wp_customize->add_setting(
			'saraswati_settings[link_color]', array(
				'default' => $defaults['link_color'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_hex_color',
				'transport' => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'saraswati_settings[link_color]',
				array(
					'label' => __( 'Link Color', 'saraswati' ),
					'section' => 'colors',
					'settings' => 'saraswati_settings[link_color]'
				)
			)
		);

		$wp_customize->add_setting(
			'saraswati_settings[link_color_hover]', array(
				'default' => $defaults['link_color_hover'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_hex_color',
				'transport' => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'saraswati_settings[link_color_hover]',
				array(
					'label' => __( 'Link Color Hover', 'saraswati' ),
					'section' => 'colors',
					'settings' => 'saraswati_settings[link_color_hover]'
				)
			)
		);

		$wp_customize->add_setting(
			'saraswati_settings[link_color_visited]', array(
				'default' => $defaults['link_color_visited'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_hex_color',
				'transport' => 'refresh',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'saraswati_settings[link_color_visited]',
				array(
					'label' => __( 'Link Color Visited', 'saraswati' ),
					'section' => 'colors',
					'settings' => 'saraswati_settings[link_color_visited]'
				)
			)
		);

		if ( ! function_exists( 'saraswati_colors_customize_register' ) && ! defined( 'SARASWATI_PREMIUM_VERSION' ) ) {
			$wp_customize->add_control(
				new Saraswati_Customize_Misc_Control(
					$wp_customize,
					'colors_get_addon_desc',
					array(
						'section' => 'colors',
						'type' => 'addon',
						'label' => __( 'More info', 'saraswati' ),
						'description' => __( 'More colors are available in Saraswati premium version. Visit wpkoi.com for more info.', 'saraswati' ),
						'url' => esc_url( SARASWATI_THEME_URL ),
						'priority' => 30,
						'settings' => ( isset( $wp_customize->selective_refresh ) ) ? array() : 'blogname'
					)
				)
			);
		}

		if ( class_exists( 'WP_Customize_Panel' ) ) {
			if ( ! $wp_customize->get_panel( 'saraswati_layout_panel' ) ) {
				$wp_customize->add_panel( 'saraswati_layout_panel', array(
					'priority' => 25,
					'title' => __( 'Layout', 'saraswati' ),
				) );
			}
		}

		// Add Layout section
		$wp_customize->add_section(
			'saraswati_layout_container',
			array(
				'title' => __( 'Container', 'saraswati' ),
				'priority' => 10,
				'panel' => 'saraswati_layout_panel'
			)
		);

		// Container width
		$wp_customize->add_setting(
			'saraswati_settings[container_width]',
			array(
				'default' => $defaults['container_width'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_integer',
				'transport' => 'postMessage'
			)
		);

		$wp_customize->add_control(
			new Saraswati_Range_Slider_Control(
				$wp_customize,
				'saraswati_settings[container_width]',
				array(
					'type' => 'saraswati-range-slider',
					'label' => __( 'Container Width', 'saraswati' ),
					'section' => 'saraswati_layout_container',
					'settings' => array(
						'desktop' => 'saraswati_settings[container_width]',
					),
					'choices' => array(
						'desktop' => array(
							'min' => 700,
							'max' => 2000,
							'step' => 5,
							'edit' => true,
							'unit' => 'px',
						),
					),
					'priority' => 0,
				)
			)
		);

		// Add Top Bar section
		$wp_customize->add_section(
			'saraswati_top_bar',
			array(
				'title' => __( 'Top Bar', 'saraswati' ),
				'priority' => 15,
				'panel' => 'saraswati_layout_panel',
			)
		);

		// Add Top Bar width
		$wp_customize->add_setting(
			'saraswati_settings[top_bar_width]',
			array(
				'default' => $defaults['top_bar_width'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add Top Bar width control
		$wp_customize->add_control(
			'saraswati_settings[top_bar_width]',
			array(
				'type' => 'select',
				'label' => __( 'Top Bar Width', 'saraswati' ),
				'section' => 'saraswati_top_bar',
				'choices' => array(
					'full' => __( 'Full', 'saraswati' ),
					'contained' => __( 'Contained', 'saraswati' )
				),
				'settings' => 'saraswati_settings[top_bar_width]',
				'priority' => 5,
				'active_callback' => 'saraswati_is_top_bar_active',
			)
		);

		// Add Top Bar inner width
		$wp_customize->add_setting(
			'saraswati_settings[top_bar_inner_width]',
			array(
				'default' => $defaults['top_bar_inner_width'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add Top Bar width control
		$wp_customize->add_control(
			'saraswati_settings[top_bar_inner_width]',
			array(
				'type' => 'select',
				'label' => __( 'Top Bar Inner Width', 'saraswati' ),
				'section' => 'saraswati_top_bar',
				'choices' => array(
					'full' => __( 'Full', 'saraswati' ),
					'contained' => __( 'Contained', 'saraswati' )
				),
				'settings' => 'saraswati_settings[top_bar_inner_width]',
				'priority' => 10,
				'active_callback' => 'saraswati_is_top_bar_active',
			)
		);

		// Add top bar alignment
		$wp_customize->add_setting(
			'saraswati_settings[top_bar_alignment]',
			array(
				'default' => $defaults['top_bar_alignment'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add navigation control
		$wp_customize->add_control(
			'saraswati_settings[top_bar_alignment]',
			array(
				'type' => 'select',
				'label' => __( 'Top Bar Alignment', 'saraswati' ),
				'section' => 'saraswati_top_bar',
				'choices' => array(
					'left' => __( 'Left', 'saraswati' ),
					'center' => __( 'Center', 'saraswati' ),
					'right' => __( 'Right', 'saraswati' )
				),
				'settings' => 'saraswati_settings[top_bar_alignment]',
				'priority' => 15,
				'active_callback' => 'saraswati_is_top_bar_active',
			)
		);

		// Add Header section
		$wp_customize->add_section(
			'saraswati_layout_header',
			array(
				'title' => __( 'Header', 'saraswati' ),
				'priority' => 20,
				'panel' => 'saraswati_layout_panel'
			)
		);

		// Add Header Layout setting
		$wp_customize->add_setting(
			'saraswati_settings[header_layout_setting]',
			array(
				'default' => $defaults['header_layout_setting'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add Header Layout control
		$wp_customize->add_control(
			'saraswati_settings[header_layout_setting]',
			array(
				'type' => 'select',
				'label' => __( 'Header Width', 'saraswati' ),
				'section' => 'saraswati_layout_header',
				'choices' => array(
					'fluid-header' => __( 'Full', 'saraswati' ),
					'contained-header' => __( 'Contained', 'saraswati' )
				),
				'settings' => 'saraswati_settings[header_layout_setting]',
				'priority' => 5
			)
		);

		// Add Inside Header Layout setting
		$wp_customize->add_setting(
			'saraswati_settings[header_inner_width]',
			array(
				'default' => $defaults['header_inner_width'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add Header Layout control
		$wp_customize->add_control(
			'saraswati_settings[header_inner_width]',
			array(
				'type' => 'select',
				'label' => __( 'Inner Header Width', 'saraswati' ),
				'section' => 'saraswati_layout_header',
				'choices' => array(
					'contained' => __( 'Contained', 'saraswati' ),
					'full-width' => __( 'Full', 'saraswati' )
				),
				'settings' => 'saraswati_settings[header_inner_width]',
				'priority' => 6
			)
		);

		// Add navigation setting
		$wp_customize->add_setting(
			'saraswati_settings[header_alignment_setting]',
			array(
				'default' => $defaults['header_alignment_setting'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add navigation control
		$wp_customize->add_control(
			'saraswati_settings[header_alignment_setting]',
			array(
				'type' => 'select',
				'label' => __( 'Header Alignment', 'saraswati' ),
				'section' => 'saraswati_layout_header',
				'choices' => array(
					'left' => __( 'Left', 'saraswati' ),
					'center' => __( 'Center', 'saraswati' ),
					'right' => __( 'Right', 'saraswati' )
				),
				'settings' => 'saraswati_settings[header_alignment_setting]',
				'priority' => 10
			)
		);

		$wp_customize->add_section(
			'saraswati_layout_navigation',
			array(
				'title' => __( 'Primary Navigation', 'saraswati' ),
				'priority' => 30,
				'panel' => 'saraswati_layout_panel'
			)
		);

		// Add navigation setting
		$wp_customize->add_setting(
			'saraswati_settings[nav_layout_setting]',
			array(
				'default' => $defaults['nav_layout_setting'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add navigation control
		$wp_customize->add_control(
			'saraswati_settings[nav_layout_setting]',
			array(
				'type' => 'select',
				'label' => __( 'Navigation Width', 'saraswati' ),
				'section' => 'saraswati_layout_navigation',
				'choices' => array(
					'fluid-nav' => __( 'Full', 'saraswati' ),
					'contained-nav' => __( 'Contained', 'saraswati' )
				),
				'settings' => 'saraswati_settings[nav_layout_setting]',
				'priority' => 15
			)
		);

		// Add navigation setting
		$wp_customize->add_setting(
			'saraswati_settings[nav_inner_width]',
			array(
				'default' => $defaults['nav_inner_width'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add navigation control
		$wp_customize->add_control(
			'saraswati_settings[nav_inner_width]',
			array(
				'type' => 'select',
				'label' => __( 'Inner Navigation Width', 'saraswati' ),
				'section' => 'saraswati_layout_navigation',
				'choices' => array(
					'contained' => __( 'Contained', 'saraswati' ),
					'full-width' => __( 'Full', 'saraswati' )
				),
				'settings' => 'saraswati_settings[nav_inner_width]',
				'priority' => 16
			)
		);

		// Add navigation setting
		$wp_customize->add_setting(
			'saraswati_settings[nav_alignment_setting]',
			array(
				'default' => $defaults['nav_alignment_setting'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add navigation control
		$wp_customize->add_control(
			'saraswati_settings[nav_alignment_setting]',
			array(
				'type' => 'select',
				'label' => __( 'Navigation Alignment', 'saraswati' ),
				'section' => 'saraswati_layout_navigation',
				'choices' => array(
					'left' => __( 'Left', 'saraswati' ),
					'center' => __( 'Center', 'saraswati' ),
					'right' => __( 'Right', 'saraswati' )
				),
				'settings' => 'saraswati_settings[nav_alignment_setting]',
				'priority' => 20
			)
		);

		// Add navigation setting
		$wp_customize->add_setting(
			'saraswati_settings[nav_position_setting]',
			array(
				'default' => $defaults['nav_position_setting'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => ( '' !== saraswati_get_setting( 'nav_position_setting' ) ) ? 'postMessage' : 'refresh'
			)
		);

		// Add navigation control
		$wp_customize->add_control(
			'saraswati_settings[nav_position_setting]',
			array(
				'type' => 'select',
				'label' => __( 'Navigation Location', 'saraswati' ),
				'section' => 'saraswati_layout_navigation',
				'choices' => array(
					'nav-below-header' => __( 'Below Header', 'saraswati' ),
					'nav-above-header' => __( 'Above Header', 'saraswati' ),
					'nav-float-right' => __( 'Float Right', 'saraswati' ),
					'nav-float-left' => __( 'Float Left', 'saraswati' ),
					'nav-left-sidebar' => __( 'Left Sidebar', 'saraswati' ),
					'nav-right-sidebar' => __( 'Right Sidebar', 'saraswati' ),
					'' => __( 'No Navigation', 'saraswati' )
				),
				'settings' => 'saraswati_settings[nav_position_setting]',
				'priority' => 22
			)
		);

		// Add navigation setting
		$wp_customize->add_setting(
			'saraswati_settings[nav_dropdown_type]',
			array(
				'default' => $defaults['nav_dropdown_type'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices'
			)
		);

		// Add navigation control
		$wp_customize->add_control(
			'saraswati_settings[nav_dropdown_type]',
			array(
				'type' => 'select',
				'label' => __( 'Navigation Dropdown', 'saraswati' ),
				'section' => 'saraswati_layout_navigation',
				'choices' => array(
					'hover' => __( 'Hover', 'saraswati' ),
					'click' => __( 'Click - Menu Item', 'saraswati' ),
					'click-arrow' => __( 'Click - Arrow', 'saraswati' )
				),
				'settings' => 'saraswati_settings[nav_dropdown_type]',
				'priority' => 22
			)
		);

		// Add navigation setting
		$wp_customize->add_setting(
			'saraswati_settings[nav_search]',
			array(
				'default' => $defaults['nav_search'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices'
			)
		);

		// Add navigation control
		$wp_customize->add_control(
			'saraswati_settings[nav_search]',
			array(
				'type' => 'select',
				'label' => __( 'Navigation Search', 'saraswati' ),
				'section' => 'saraswati_layout_navigation',
				'choices' => array(
					'enable' => __( 'Enable', 'saraswati' ),
					'disable' => __( 'Disable', 'saraswati' )
				),
				'settings' => 'saraswati_settings[nav_search]',
				'priority' => 23
			)
		);

		// Add content setting
		$wp_customize->add_setting(
			'saraswati_settings[content_layout_setting]',
			array(
				'default' => $defaults['content_layout_setting'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add content control
		$wp_customize->add_control(
			'saraswati_settings[content_layout_setting]',
			array(
				'type' => 'select',
				'label' => __( 'Content Layout', 'saraswati' ),
				'section' => 'saraswati_layout_container',
				'choices' => array(
					'separate-containers' => __( 'Separate Containers', 'saraswati' ),
					'one-container' => __( 'One Container', 'saraswati' )
				),
				'settings' => 'saraswati_settings[content_layout_setting]',
				'priority' => 25
			)
		);

		$wp_customize->add_section(
			'saraswati_layout_sidecontent',
			array(
				'title' => __( 'Fixed Side Content', 'saraswati' ),
				'priority' => 39,
				'panel' => 'saraswati_layout_panel'
			)
		);
		
		$wp_customize->add_setting(
			'saraswati_settings[fixed_side_content]',
			array(
				'default' => $defaults['fixed_side_content'],
				'type' => 'option',
				'sanitize_callback' => 'wp_kses_post',
			)
		);

		$wp_customize->add_control(
			'saraswati_settings[fixed_side_content]',
			array(
				'type' 		 => 'textarea',
				'label'      => __( 'Fixed Side Content', 'saraswati' ),
				'description'=> __( 'Content that You want to display fixed on the left.', 'saraswati' ),
				'section'    => 'saraswati_layout_sidecontent',
				'settings'   => 'saraswati_settings[fixed_side_content]',
			)
		);

		$wp_customize->add_section(
			'saraswati_layout_sidebars',
			array(
				'title' => __( 'Sidebars', 'saraswati' ),
				'priority' => 40,
				'panel' => 'saraswati_layout_panel'
			)
		);

		// Add Layout setting
		$wp_customize->add_setting(
			'saraswati_settings[layout_setting]',
			array(
				'default' => $defaults['layout_setting'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices'
			)
		);

		// Add Layout control
		$wp_customize->add_control(
			'saraswati_settings[layout_setting]',
			array(
				'type' => 'select',
				'label' => __( 'Sidebar Layout', 'saraswati' ),
				'section' => 'saraswati_layout_sidebars',
				'choices' => array(
					'left-sidebar' => __( 'Sidebar / Content', 'saraswati' ),
					'right-sidebar' => __( 'Content / Sidebar', 'saraswati' ),
					'no-sidebar' => __( 'Content (no sidebars)', 'saraswati' ),
					'both-sidebars' => __( 'Sidebar / Content / Sidebar', 'saraswati' ),
					'both-left' => __( 'Sidebar / Sidebar / Content', 'saraswati' ),
					'both-right' => __( 'Content / Sidebar / Sidebar', 'saraswati' )
				),
				'settings' => 'saraswati_settings[layout_setting]',
				'priority' => 30
			)
		);

		// Add Layout setting
		$wp_customize->add_setting(
			'saraswati_settings[blog_layout_setting]',
			array(
				'default' => $defaults['blog_layout_setting'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices'
			)
		);

		// Add Layout control
		$wp_customize->add_control(
			'saraswati_settings[blog_layout_setting]',
			array(
				'type' => 'select',
				'label' => __( 'Blog Sidebar Layout', 'saraswati' ),
				'section' => 'saraswati_layout_sidebars',
				'choices' => array(
					'left-sidebar' => __( 'Sidebar / Content', 'saraswati' ),
					'right-sidebar' => __( 'Content / Sidebar', 'saraswati' ),
					'no-sidebar' => __( 'Content (no sidebars)', 'saraswati' ),
					'both-sidebars' => __( 'Sidebar / Content / Sidebar', 'saraswati' ),
					'both-left' => __( 'Sidebar / Sidebar / Content', 'saraswati' ),
					'both-right' => __( 'Content / Sidebar / Sidebar', 'saraswati' )
				),
				'settings' => 'saraswati_settings[blog_layout_setting]',
				'priority' => 35
			)
		);

		// Add Layout setting
		$wp_customize->add_setting(
			'saraswati_settings[single_layout_setting]',
			array(
				'default' => $defaults['single_layout_setting'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices'
			)
		);

		// Add Layout control
		$wp_customize->add_control(
			'saraswati_settings[single_layout_setting]',
			array(
				'type' => 'select',
				'label' => __( 'Single Post Sidebar Layout', 'saraswati' ),
				'section' => 'saraswati_layout_sidebars',
				'choices' => array(
					'left-sidebar' => __( 'Sidebar / Content', 'saraswati' ),
					'right-sidebar' => __( 'Content / Sidebar', 'saraswati' ),
					'no-sidebar' => __( 'Content (no sidebars)', 'saraswati' ),
					'both-sidebars' => __( 'Sidebar / Content / Sidebar', 'saraswati' ),
					'both-left' => __( 'Sidebar / Sidebar / Content', 'saraswati' ),
					'both-right' => __( 'Content / Sidebar / Sidebar', 'saraswati' )
				),
				'settings' => 'saraswati_settings[single_layout_setting]',
				'priority' => 36
			)
		);

		$wp_customize->add_section(
			'saraswati_layout_footer',
			array(
				'title' => __( 'Footer', 'saraswati' ),
				'priority' => 50,
				'panel' => 'saraswati_layout_panel'
			)
		);

		// Add footer setting
		$wp_customize->add_setting(
			'saraswati_settings[footer_layout_setting]',
			array(
				'default' => $defaults['footer_layout_setting'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add content control
		$wp_customize->add_control(
			'saraswati_settings[footer_layout_setting]',
			array(
				'type' => 'select',
				'label' => __( 'Footer Width', 'saraswati' ),
				'section' => 'saraswati_layout_footer',
				'choices' => array(
					'fluid-footer' => __( 'Full', 'saraswati' ),
					'contained-footer' => __( 'Contained', 'saraswati' )
				),
				'settings' => 'saraswati_settings[footer_layout_setting]',
				'priority' => 40
			)
		);

		// Add footer setting
		$wp_customize->add_setting(
			'saraswati_settings[footer_widgets_inner_width]',
			array(
				'default' => $defaults['footer_widgets_inner_width'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
			)
		);

		// Add content control
		$wp_customize->add_control(
			'saraswati_settings[footer_widgets_inner_width]',
			array(
				'type' => 'select',
				'label' => __( 'Inner Footer Widgets Width', 'saraswati' ),
				'section' => 'saraswati_layout_footer',
				'choices' => array(
					'contained' => __( 'Contained', 'saraswati' ),
					'full-width' => __( 'Full', 'saraswati' )
				),
				'settings' => 'saraswati_settings[footer_widgets_inner_width]',
				'priority' => 41
			)
		);

		// Add footer setting
		$wp_customize->add_setting(
			'saraswati_settings[footer_inner_width]',
			array(
				'default' => $defaults['footer_inner_width'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add content control
		$wp_customize->add_control(
			'saraswati_settings[footer_inner_width]',
			array(
				'type' => 'select',
				'label' => __( 'Inner Footer Width', 'saraswati' ),
				'section' => 'saraswati_layout_footer',
				'choices' => array(
					'contained' => __( 'Contained', 'saraswati' ),
					'full-width' => __( 'Full', 'saraswati' )
				),
				'settings' => 'saraswati_settings[footer_inner_width]',
				'priority' => 41
			)
		);

		// Add footer widget setting
		$wp_customize->add_setting(
			'saraswati_settings[footer_widget_setting]',
			array(
				'default' => $defaults['footer_widget_setting'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add footer widget control
		$wp_customize->add_control(
			'saraswati_settings[footer_widget_setting]',
			array(
				'type' => 'select',
				'label' => __( 'Footer Widgets', 'saraswati' ),
				'section' => 'saraswati_layout_footer',
				'choices' => array(
					'0' => '0',
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4',
					'5' => '5'
				),
				'settings' => 'saraswati_settings[footer_widget_setting]',
				'priority' => 45
			)
		);

		// Add footer widget setting
		$wp_customize->add_setting(
			'saraswati_settings[footer_bar_alignment]',
			array(
				'default' => $defaults['footer_bar_alignment'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices',
				'transport' => 'postMessage'
			)
		);

		// Add footer widget control
		$wp_customize->add_control(
			'saraswati_settings[footer_bar_alignment]',
			array(
				'type' => 'select',
				'label' => __( 'Footer Bar Alignment', 'saraswati' ),
				'section' => 'saraswati_layout_footer',
				'choices' => array(
					'left' => __( 'Left','saraswati' ),
					'center' => __( 'Center','saraswati' ),
					'right' => __( 'Right','saraswati' )
				),
				'settings' => 'saraswati_settings[footer_bar_alignment]',
				'priority' => 47,
				'active_callback' => 'saraswati_is_footer_bar_active'
			)
		);

		// Add back to top setting
		$wp_customize->add_setting(
			'saraswati_settings[back_to_top]',
			array(
				'default' => $defaults['back_to_top'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_choices'
			)
		);

		// Add content control
		$wp_customize->add_control(
			'saraswati_settings[back_to_top]',
			array(
				'type' => 'select',
				'label' => __( 'Back to Top Button', 'saraswati' ),
				'section' => 'saraswati_layout_footer',
				'choices' => array(
					'enable' => __( 'Enable', 'saraswati' ),
					'' => __( 'Disable', 'saraswati' )
				),
				'settings' => 'saraswati_settings[back_to_top]',
				'priority' => 50
			)
		);

		// Add Layout section
		$wp_customize->add_section(
			'saraswati_blog_section',
			array(
				'title' => __( 'Blog', 'saraswati' ),
				'priority' => 55,
				'panel' => 'saraswati_layout_panel'
			)
		);

		$wp_customize->add_setting(
			'saraswati_settings[blog_header_image]',
			array(
				'default' => $defaults['blog_header_image'],
				'type' => 'option',
				'sanitize_callback' => 'esc_url_raw'
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'saraswati_settings[blog_header_image]',
				array(
					'label' => __( 'First Blog Header image', 'saraswati' ),
					'section' => 'saraswati_blog_section',
					'settings' => 'saraswati_settings[blog_header_image]',
					'description' => __( 'A standing image looks better. (Recommended size: 640*800px)', 'saraswati' )
				)
			)
		);

		// Blog header texts
		$wp_customize->add_setting(
			'saraswati_settings[blog_header_title]',
			array(
				'default' => $defaults['blog_header_title'],
				'type' => 'option',
				'sanitize_callback' => 'wp_kses_post',
			)
		);

		$wp_customize->add_control(
			'saraswati_settings[blog_header_title]',
			array(
				'type' 		 => 'textarea',
				'label'      => __( 'Blog Header title', 'saraswati' ),
				'section'    => 'saraswati_blog_section',
				'settings'   => 'saraswati_settings[blog_header_title]',
			)
		);
		
		$wp_customize->add_setting(
			'saraswati_settings[blog_header_text]',
			array(
				'default' => $defaults['blog_header_text'],
				'type' => 'option',
				'sanitize_callback' => 'wp_kses_post',
			)
		);

		$wp_customize->add_control(
			'saraswati_settings[blog_header_text]',
			array(
				'type' 		 => 'textarea',
				'label'      => __( 'Blog Header text', 'saraswati' ),
				'section'    => 'saraswati_blog_section',
				'settings'   => 'saraswati_settings[blog_header_text]',
			)
		);
		
		$wp_customize->add_setting(
			'saraswati_settings[blog_header_button_text]',
			array(
				'default' => $defaults['blog_header_button_text'],
				'type' => 'option',
				'sanitize_callback' => 'esc_html',
			)
		);

		$wp_customize->add_control(
			'saraswati_settings[blog_header_button_text]',
			array(
				'type' 		 => 'text',
				'label'      => __( 'Blog Header button text', 'saraswati' ),
				'section'    => 'saraswati_blog_section',
				'settings'   => 'saraswati_settings[blog_header_button_text]',
			)
		);
		
		$wp_customize->add_setting(
			'saraswati_settings[blog_header_button_url]',
			array(
				'default' => $defaults['blog_header_button_url'],
				'type' => 'option',
				'sanitize_callback' => 'esc_url',
			)
		);

		$wp_customize->add_control(
			'saraswati_settings[blog_header_button_url]',
			array(
				'type' 		 => 'text',
				'label'      => __( 'Blog Header button url', 'saraswati' ),
				'section'    => 'saraswati_blog_section',
				'settings'   => 'saraswati_settings[blog_header_button_url]',
			)
		);

		// Add Layout setting
		$wp_customize->add_setting(
			'saraswati_settings[post_content]',
			array(
				'default' => $defaults['post_content'],
				'type' => 'option',
				'sanitize_callback' => 'saraswati_sanitize_blog_excerpt'
			)
		);

		// Add Layout control
		$wp_customize->add_control(
			'blog_content_control',
			array(
				'type' => 'select',
				'label' => __( 'Content Type', 'saraswati' ),
				'section' => 'saraswati_blog_section',
				'choices' => array(
					'full' => __( 'Full', 'saraswati' ),
					'excerpt' => __( 'Excerpt', 'saraswati' )
				),
				'settings' => 'saraswati_settings[post_content]',
				'priority' => 10
			)
		);

		if ( ! function_exists( 'saraswati_blog_customize_register' ) && ! defined( 'SARASWATI_PREMIUM_VERSION' ) ) {
			$wp_customize->add_control(
				new Saraswati_Customize_Misc_Control(
					$wp_customize,
					'blog_get_addon_desc',
					array(
						'section' => 'saraswati_blog_section',
						'type' => 'addon',
						'label' => __( 'Learn more', 'saraswati' ),
						'description' => __( 'More options are available for this section in our premium version.', 'saraswati' ),
						'url' => esc_url( SARASWATI_THEME_URL ),
						'priority' => 30,
						'settings' => ( isset( $wp_customize->selective_refresh ) ) ? array() : 'blogname'
					)
				)
			);
		}

		// Add Performance section
		$wp_customize->add_section(
			'saraswati_general_section',
			array(
				'title' => __( 'General', 'saraswati' ),
				'priority' => 99
			)
		);

		if ( ! apply_filters( 'saraswati_fontawesome_essentials', false ) ) {
			$wp_customize->add_setting(
				'saraswati_settings[font_awesome_essentials]',
				array(
					'default' => $defaults['font_awesome_essentials'],
					'type' => 'option',
					'sanitize_callback' => 'saraswati_sanitize_checkbox'
				)
			);

			$wp_customize->add_control(
				'saraswati_settings[font_awesome_essentials]',
				array(
					'type' => 'checkbox',
					'label' => __( 'Load essential icons only', 'saraswati' ),
					'description' => __( 'Load essential Font Awesome icons instead of the full library.', 'saraswati' ),
					'section' => 'saraswati_general_section',
					'settings' => 'saraswati_settings[font_awesome_essentials]',
				)
			);
		}

		// Add Saraswati Premium section
		if ( ! defined( 'SARASWATI_PREMIUM_VERSION' ) ) {
			$wp_customize->add_section(
				new Saraswati_Upsell_Section( $wp_customize, 'saraswati_upsell_section',
					array(
						'pro_text' => __( 'Get Premium for more!', 'saraswati' ),
						'pro_url' => esc_url( SARASWATI_THEME_URL ),
						'capability' => 'edit_theme_options',
						'priority' => 555,
						'type' => 'saraswati-upsell-section',
					)
				)
			);
		}
	}
}

if ( ! function_exists( 'saraswati_customizer_live_preview' ) ) {
	add_action( 'customize_preview_init', 'saraswati_customizer_live_preview', 100 );
	/**
	 * Add our live preview scripts
	 *
	 */
	function saraswati_customizer_live_preview() {
		wp_enqueue_script( 'saraswati-themecustomizer', trailingslashit( get_template_directory_uri() ) . 'inc/customizer/controls/js/customizer-live-preview.js', array( 'customize-preview' ), SARASWATI_VERSION, true );
	}
}
